bankaccountsystem package

# Introduction
The packagfe performs the essential functions of banking software. 
•	Create a new account
•	Make deposits and withdrawals
•	Exchange money
•	View the account’s records 
